pub trait CookieBuilder: Sized {
// Required method
fn new(name: String, value: String) -> Self;
}Expand description
Internal trait for abstracting cookie construction across different cookie implementations.
This trait allows the parser to work with different cookie types (e.g., cookie::Cookie,
reqwest::cookie::Cookie) by providing a common interface for creating cookies.
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.
Implementations on Foreign Types
Sourceimpl CookieBuilder for Cookie<'static>
Implementation of CookieBuilder for cookie::Cookie
impl CookieBuilder for Cookie<'static>
Implementation of CookieBuilder for cookie::Cookie