CookieBuilder

Trait CookieBuilder 

pub trait CookieBuilder: Sized {
    // Required method
    fn new(name: String, value: String) -> Self;
}
Internal trait for abstracting cookie construction across different cookie implementations.

This trait allows the parser to work with different cookie types (e.g., cookie::Cookie, reqwest::cookie::Cookie) by providing a common interface for creating cookies.

Required Methods

fn new(name: String, value: String) -> Self

Create a new cookie with the given name and value.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl CookieBuilder for Cookie<'static>

Implementation of CookieBuilder for cookie::Cookie

Source

fn new(name: String, value: String) -> Self

Implementors